@@ -118,7 +118,8 @@ public class OXReseller extends OXCommonImpl implements OXResellerInterface {
 
         try {
             int pid = 0;
-            if( ClientAdminThread.cache.getMasterCredentials().getLogin().equals(creds.getLogin()) ) {
+            final Credentials masterCredentials = ClientAdminThread.cache.getMasterCredentials();
+            if( null != masterCredentials && masterCredentials.getLogin().equals(creds.getLogin()) ) {
                 basicauth.doAuthentication(creds);
             } else {
                 resellerauth.doAuthentication(creds);
@@ -196,7 +197,8 @@ public class OXReseller extends OXCommonImpl implements OXResellerInterface {
         }
         int pid = 0;
         try {
-            if( ClientAdminThread.cache.getMasterCredentials().getLogin().equals(creds.getLogin()) ) {
+            final Credentials masterCredentials = ClientAdminThread.cache.getMasterCredentials();
+            if( null != masterCredentials && masterCredentials.getLogin().equals(creds.getLogin()) ) {
                 basicauth.doAuthentication(creds);
             } else {
                 resellerauth.doAuthentication(creds);
@@ -229,7 +231,7 @@ public class OXReseller extends OXCommonImpl implements OXResellerInterface {
                     throw new OXResellerException(Code.SUBSUBADMIN_NOT_ALLOWED_TO_CHANGE_RESTRICTIONS);
                 }
             }
-            
+
             adm.setParentId(pid);
 
             checkRestrictionsPerSubadmin(adm);
@@ -269,7 +271,8 @@ public class OXReseller extends OXCommonImpl implements OXResellerInterface {
 
         try {
             boolean isMaster = false;
-            if( ClientAdminThread.cache.getMasterCredentials().getLogin().equals(creds.getLogin()) ) {
+            final Credentials masterCredentials = ClientAdminThread.cache.getMasterCredentials();
+            if( null != masterCredentials && masterCredentials.getLogin().equals(creds.getLogin()) ) {
                 basicauth.doAuthentication(creds);
                 isMaster = true;
             } else {
@@ -285,7 +288,7 @@ public class OXReseller extends OXCommonImpl implements OXResellerInterface {
                 ResellerAdmin sadmdata = oxresell.getData(new ResellerAdmin[] { new ResellerAdmin(creds.getLogin(), creds.getPassword()) })[0];
                 ResellerAdmin dadmdata = oxresell.getData(new ResellerAdmin[] { adm })[0];
                 if( !dadmdata.getParentId().equals(sadmdata.getId()) ) {
-                    throw new OXResellerException(Code.SUBADMIN_DOES_NOT_BELONG_TO_SUBADMIN, dadmdata.getName(), sadmdata.getName());   
+                    throw new OXResellerException(Code.SUBADMIN_DOES_NOT_BELONG_TO_SUBADMIN, dadmdata.getName(), sadmdata.getName());
                 }
             }
             if (adm.getName() == null) {
@@ -323,7 +326,8 @@ public class OXReseller extends OXCommonImpl implements OXResellerInterface {
         }
 
         try {
-            if (ClientAdminThread.cache.getMasterCredentials().getLogin().equals(creds.getLogin())) {
+            final Credentials masterCredentials = ClientAdminThread.cache.getMasterCredentials();
+            if( null != masterCredentials && masterCredentials.getLogin().equals(creds.getLogin())) {
                 basicauth.doAuthentication(creds);
             } else {
                 resellerauth.doAuthentication(creds);
@@ -376,7 +380,8 @@ public class OXReseller extends OXCommonImpl implements OXResellerInterface {
 
         try {
             int pid = 0;
-            if( ClientAdminThread.cache.getMasterCredentials().getLogin().equals(creds.getLogin()) ) {
+            final Credentials masterCredentials = ClientAdminThread.cache.getMasterCredentials();
+            if( null != masterCredentials && masterCredentials.getLogin().equals(creds.getLogin()) ) {
                 basicauth.doAuthentication(creds);
             } else {
                 resellerauth.doAuthentication(creds);
@@ -495,7 +500,8 @@ public class OXReseller extends OXCommonImpl implements OXResellerInterface {
         }
 
         try {
-            if( ClientAdminThread.cache.getMasterCredentials().getLogin().equals(creds.getLogin()) ) {
+            final Credentials masterCredentials = ClientAdminThread.cache.getMasterCredentials();
+            if( null != masterCredentials && masterCredentials.getLogin().equals(creds.getLogin()) ) {
                 basicauth.doAuthentication(creds);
                 return oxresell.list(search_pattern);
             } else {
@@ -578,7 +584,7 @@ public class OXReseller extends OXCommonImpl implements OXResellerInterface {
 
     /**
      * throws {@link InvalidDataException} when neither id nor name supplied
-     * 
+     *
      * @param admins
      * @throws InvalidDataException
      */
@@ -597,7 +603,7 @@ public class OXReseller extends OXCommonImpl implements OXResellerInterface {
 
     /**
      * Checks whether either id or name is specified
-     * 
+     *
      * @param adm
      * @throws InvalidDataException
      */
@@ -612,7 +618,7 @@ public class OXReseller extends OXCommonImpl implements OXResellerInterface {
      * Restriction id. Check whether Restrictions can be applied to subadmin. If not, throw {@link InvalidDataException} or
      * {@link StorageException} if there are no Restrictions defined within the database. Check whether Restrictions contain duplicate
      * Restriction entries and throws {@link InvalidDataException} if that is the case.
-     * 
+     *
      * @throws StorageException
      * @throws InvalidDataException
      * @throws OXResellerException
